package com.ruoyi.szxc.mapper;

import java.util.List;
import com.ruoyi.szxc.domain.SzxcZcssxj;

/**
 * 资产设施巡检Mapper接口
 * 
 * @author hs
 * @date 2024-04-02
 */
public interface SzxcZcssxjMapper 
{
    /**
     * 查询资产设施巡检
     * 
     * @param id 资产设施巡检主键
     * @return 资产设施巡检
     */
    public SzxcZcssxj selectSzxcZcssxjById(Long id);

    /**
     * 查询资产设施巡检列表
     * 
     * @param szxcZcssxj 资产设施巡检
     * @return 资产设施巡检集合
     */
    public List<SzxcZcssxj> selectSzxcZcssxjList(SzxcZcssxj szxcZcssxj);

    /**
     * 新增资产设施巡检
     * 
     * @param szxcZcssxj 资产设施巡检
     * @return 结果
     */
    public int insertSzxcZcssxj(SzxcZcssxj szxcZcssxj);

    /**
     * 修改资产设施巡检
     * 
     * @param szxcZcssxj 资产设施巡检
     * @return 结果
     */
    public int updateSzxcZcssxj(SzxcZcssxj szxcZcssxj);

    /**
     * 删除资产设施巡检
     * 
     * @param id 资产设施巡检主键
     * @return 结果
     */
    public int deleteSzxcZcssxjById(Long id);

    /**
     * 批量删除资产设施巡检
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSzxcZcssxjByIds(Long[] ids);
}
